---
delivery_guarantee: "at_least_once"
description: "The Vector `kafka` source ingests data through Kafka 0.9 or later and outputs `log` events."
event_types: ["log"]
issues_url: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22source%3A+kafka%22
operating_systems: ["linux","macos","windows"]
sidebar_label: "kafka|[\"log\"]"
source_url: https://github.com/timberio/vector/tree/master/src/sources/kafka.rs
status: "beta"
title: "Kafka Source"
unsupported_operating_systems: []
---

The Vector `kafka` source ingests data through Kafka 0.9 or later and outputs [`log`][docs.data-model.log] events.

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/reference/sources/kafka.md.erb
-->

## Configuration

import Tabs from '@theme/Tabs';

<Tabs
  block={true}
  defaultValue="common"
  values={[
    { label: 'Common', value: 'common', },
    { label: 'Advanced', value: 'advanced', },
  ]
}>

import TabItem from '@theme/TabItem';

<TabItem value="common">

import CodeHeader from '@site/src/components/CodeHeader';

<CodeHeader fileName="vector.toml" learnMoreUrl="/docs/setup/configuration/"/ >

```toml
[sources.my_source_id]
  # REQUIRED
  type = "kafka" # must be: "kafka"
  bootstrap_servers = "10.14.22.123:9092,10.14.23.332:9092" # example
  group_id = "consumer-group-name" # example
  topics = ["^(prefix1|prefix2)-.+", "topic-1", "topic-2"] # example

  # OPTIONAL
  key_field = "user_id" # example, no default
```

</TabItem>
<TabItem value="advanced">

<CodeHeader fileName="vector.toml" learnMoreUrl="/docs/setup/configuration/" />

```toml
[sources.my_source_id]
  # REQUIRED
  type = "kafka" # must be: "kafka"
  bootstrap_servers = "10.14.22.123:9092,10.14.23.332:9092" # example
  group_id = "consumer-group-name" # example
  topics = ["^(prefix1|prefix2)-.+", "topic-1", "topic-2"] # example

  # OPTIONAL
  auto_offset_reset = "largest" # default
  key_field = "user_id" # example, no default
  session_timeout_ms = 10000 # default, milliseconds
```

</TabItem>

</Tabs>

## Options

import Fields from '@site/src/components/Fields';

import Field from '@site/src/components/Field';

<Fields filters={true}>


<Field
  common={false}
  defaultValue={"largest"}
  enumValues={null}
  examples={["smallest","earliest","beginning","largest","latest","end","error"]}
  name={"auto_offset_reset"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  >

### auto_offset_reset

If offsets for consumer group do not exist, set them using this strategy. [librdkafka documentation][urls.lib_rdkafka_config] for `auto.offset.reset` option for explanation.


</Field>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["10.14.22.123:9092,10.14.23.332:9092"]}
  name={"bootstrap_servers"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  >

### bootstrap_servers

A comma-separated list of host and port pairs that are the addresses of the Kafka brokers in a &quot;bootstrap&quot; Kafka cluster that a Kafka client connects to initially to bootstrap itself.


</Field>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["consumer-group-name"]}
  name={"group_id"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  >

### group_id

The consumer group name to be used to consume events from Kafka.



</Field>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["user_id"]}
  name={"key_field"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  >

### key_field

The log field name to use for the topic key. If unspecified, the key would not be added to the log event. If the message has null key, then this field would not be added to the log event.


</Field>


<Field
  common={false}
  defaultValue={10000}
  enumValues={null}
  examples={[5000,10000]}
  name={"session_timeout_ms"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"int"}
  unit={"milliseconds"}
  >

### session_timeout_ms

The Kafka session timeout in milliseconds.



</Field>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[["^(prefix1|prefix2)-.+","topic-1","topic-2"]]}
  name={"topics"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"[string]"}
  unit={null}
  >

### topics

The Kafka topics names to read events from. Regex is supported if the topic begins with `^`.



</Field>


</Fields>

## Output

The `kafka` source ingests data through Kafka 0.9 or later and outputs [`log`][docs.data-model.log] events.
For example:

```javascript
{
  "message": "Started GET / for 127.0.0.1 at 2012-03-10 14:28:14 +0100",
  "timestamp": "2019-11-01T21:15:47+00:00"
}
```
More detail on the output schema is below.

<Fields filters={true}>


<Field
  defaultValue={null}
  enumValues={null}
  examples={["Started GET / for 127.0.0.1 at 2012-03-10 14:28:14 +0100"]}
  name={"message"}
  path={null}
  required={true}
  type={"string"}
  >

### message

The raw event message, unaltered.



</Field>


<Field
  defaultValue={null}
  enumValues={null}
  examples={["2019-11-01T21:15:47+00:00"]}
  name={"timestamp"}
  path={null}
  required={true}
  type={"timestamp"}
  >

### timestamp

The exact time the event was ingested.


</Field>


</Fields>

## How It Works

### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the [Environment Variables][docs.configuration#environment-variables]
section.


[docs.configuration#environment-variables]: /docs/setup/configuration/#environment-variables
[docs.data-model.log]: /docs/about/data-model/log/
[urls.lib_rdkafka_config]: https://github.com/edenhill/librdkafka/blob/master/CONFIGURATION.md
